Exception: BaseCradle::TaskNotPendingError

Inherits:
ConflictError show all
Defined in:
lib/basecradle/errors.rb

Overview

task_not_pending — the task cannot be cancelled because it is no longer pending: it has already activated, was blocked, or was already cancelled.

Instance Attribute Summary

Attributes inherited from Error

#code, #detail, #instance, #problem, #status, #title

Method Summary

Methods inherited from Error

from_response, #initialize

Constructor Details

This class inherits a constructor from BaseCradle::Error